@@ -16,6 +16,8 @@
 """
 Base URL handler.
 """
+# pylint: disable=assignment-from-none, catching-non-exception, no-member
+
 import sys
 import os
 import urllib.parse
@@ -54,7 +56,7 @@ from .const import (
 from ..url import url_fix_wayback_query
 
 # schemes that are invalid with an empty hostname
-scheme_requires_host = ("ftp", "http", "telnet")
+scheme_requires_host = ("ftp", "http")
 
 
 def urljoin(parent, url):
@@ -382,11 +384,11 @@ class UrlBase:
         Add a warning string.
         """
         item = (tag, s)
-        if (
-            item not in self.warnings
-            and tag not in self.aggregate.config["ignorewarnings"]
-        ):
-            self.warnings.append(item)
+        if item not in self.warnings:
+            if tag in self.aggregate.config["ignorewarnings"]:
+                self.add_info(s)
+            else:
+                self.warnings.append(item)
 
     def add_info(self, s):
         """
